@@ -166,9 +166,9 @@ class LinearPerturbationBoltzmann(LinearPerturbationBase):
             for j, onek in enumerate(kk):
                 grid, y, meta, keep_lna0 = self._compute_fields(onek, grid=np.log(a))
                 delta = y[1:, 1]
-                theta = y[1:, 2] * onek
+                theta = y[1:, 2] * onek 
                 delta_b = y[1:, 3]
-                theta_b = y[1:, 4] * onek
+                theta_b = y[1:, 4] * onek 
                 H = self._background.H(a) / (self._params.H0 * self._params.rh)
                 omega_nu_m = 0.0
                 P_nu_m = 0.0
@@ -176,8 +176,8 @@ class LinearPerturbationBoltzmann(LinearPerturbationBase):
                 omega_plus_p_m_tot = self._params.omega_m
                 # include massive neutrinos in the total matter term
                 if self._params.N_massive_nu != 0:
-                    omega_nu_m = self._wrapper.omega_nu_m(a)
-                    P_nu_m = self._wrapper.P_nu_m(a)
+                    omega_nu_m = self._wrapper.omega_nu_m_ufunc(a)
+                    P_nu_m = self._wrapper.P_nu_m_ufunc(a)
                     omega_m_tot += omega_nu_m / a
                     omega_plus_p_m_tot += (omega_nu_m + P_nu_m) / a
                     delta_nu_m = self._wrapper.delta_nu_m_ufunc(a, y[1:])
