@@ -130,7 +130,6 @@ class Cosmo(object):
             folder = data["folder"]
             checks = data["checks"]
             enrich_params = data["enrich_params"]
-            self._module = data["module"]
 
             try:
                 print("load wrapper from", folder)
@@ -143,7 +142,6 @@ class Cosmo(object):
             module, checks, enrich_params = core_file_handling.load_core_files(
                 self.core_equations_files, self.model_config
             )
-            self._module = module
             compilation_flags = self.model_config.main.compilation_flags.split(" ")
             wrapper = module.compile_and_load(compilation_flags=compilation_flags)
 
@@ -385,7 +383,6 @@ class Cosmo(object):
         self.lin_pert_tab = LinearPerturbationTable(self.lin_pert)
 
         if self.nonlin_pert is None:
-
             self.projection = FakeProjection()
             return
 
@@ -436,12 +433,12 @@ class Cosmo(object):
         # critical density at z=0 [h^2 M_sun Mpc^-3]
         derived_parameters.rho_crit = (
             3.0
-            * derived_parameters.H0**2
+            * derived_parameters.H0 ** 2
             / (8.0 * np.pi * params.G)
             * 1e6
             * params.mpc
             / params.msun
-            / params.h**2
+            / params.h ** 2
         )
         # TODO: check omega_gamma and omega_neu expressions
         # omega_photon (see Dodelson eq. 2.70) ** express in terms of H0? **)
@@ -452,14 +449,14 @@ class Cosmo(object):
         if params.N_massive_nu != 0:
             derived_parameters.N_eff = (
                 params.N_massless_nu
-                + self.model_specific_parameters.T_mnu**4
+                + self.model_specific_parameters.T_mnu ** 4
                 * (4 / 11) ** -(4 / 3)
                 * params.N_massive_nu
             )
 
         derived_parameters.rho_gamma_eV = (
-            (3 * 100**2 / (8 * np.pi * params.G))
-            * params.hbar**3
+            (3 * 100 ** 2 / (8 * np.pi * params.G))
+            * params.hbar ** 3
             * (1 / (params.mpc * 1e-3)) ** 2
             * (1 / (params.evc2))
             * (params.c * 1e3) ** 3
@@ -468,7 +465,7 @@ class Cosmo(object):
         derived_parameters.T_0 = params.Tcmb * ((4 / 11) ** (1 / 3))
         derived_parameters.rho_mnu_eV = (
             3.0
-            * derived_parameters.H0**2
+            * derived_parameters.H0 ** 2
             * (params.hbar) ** 3
             * (params.c * 1e3) ** 3
             / (8 * np.pi * params.G)
@@ -478,7 +475,7 @@ class Cosmo(object):
         )
 
         derived_parameters.omega_gamma_prefactor = (
-            np.pi**2
+            np.pi ** 2
             / 15
             * (2.725 * params.kb) ** 4
             / (derived_parameters.rho_gamma_eV)
@@ -486,7 +483,7 @@ class Cosmo(object):
         derived_parameters.omega_gamma = (
             derived_parameters.omega_gamma_prefactor
             * (params.Tcmb / 2.725) ** 4
-            / params.h**2
+            / params.h ** 2
             * nudge[1]
         )
         derived_parameters.omega_neu = (
@@ -576,13 +573,13 @@ class Cosmo(object):
 
         # derived_parameters.H_0 = 100 * params.h
 
-        omh2 = params.omega_m * params.h**2
+        omh2 = params.omega_m * params.h ** 2
 
         derived_parameters._sigma_27 = params.Tcmb / 2.7  # Normalised CMB temperature
 
         # Wave vector values
         derived_parameters._k_eq = (
-            7.46e-2 * omh2 * derived_parameters._sigma_27**-2
+            7.46e-2 * omh2 * derived_parameters._sigma_27 ** -2
         )  # Eq. (3), units: Mpc^-1
 
         # Redshift values
@@ -590,15 +587,15 @@ class Cosmo(object):
         # it to avoid confusion
         # Redshift at matter-radiation equality, Eq. (2)
         derived_parameters._z_equality = (
-            2.5e4 * omh2 * derived_parameters._sigma_27**-4
+            2.5e4 * omh2 * derived_parameters._sigma_27 ** -4
         )
-        b_1 = 0.313 * omh2**-0.419 * (1.0 + 0.607 * omh2**0.674)
-        b_2 = 0.238 * omh2**0.223
+        b_1 = 0.313 * omh2 ** -0.419 * (1.0 + 0.607 * omh2 ** 0.674)
+        b_2 = 0.238 * omh2 ** 0.223
         derived_parameters._z_drag = (
             1291.0
-            * (omh2**0.251)
-            / (1.0 + 0.659 * omh2**0.828)
-            * (1.0 + b_1 * (params.omega_b * params.h**2) ** b_2)
+            * (omh2 ** 0.251)
+            / (1.0 + 0.659 * omh2 ** 0.828)
+            * (1.0 + b_1 * (params.omega_b * params.h ** 2) ** b_2)
         )  # Redshift at drag epoch, Eq. (4)
 
         # Comoving distance values
@@ -648,9 +645,9 @@ class Cosmo(object):
         R = (
             31.5
             * params.omega_b
-            * params.h**2
+            * params.h ** 2
             * derived_parameters._sigma_27 ** (-4)
-            * (z / 10**3) ** (-1.0)
+            * (z / 10 ** 3) ** (-1.0)
         )
 
         return R
