@@ -163,9 +163,9 @@ def initial_cosmics():
     Initial conditions as defined in Cosmics
     """
     eta_0 = Min(1e-3 / k, 1e-1 * h)
-    adotrad = 2.8948e-7 * Tcmb**2
+    adotrad = sp.sqrt(omega_r)/rh
 
-    a_0 = eta_0 / h * adotrad
+    a_0 = eta_0 * adotrad
 
     H_a0 = H.subs({a: a_0})  # H as function of t
     ha = H_a0 / H0 / rh
@@ -301,9 +301,9 @@ def initial_class():
     # the initial time is same as in Cosmics,
     # we do not set it iteratively as in CLASS
     eta_0_approx = Min(1e-3 / k, 1e-1 * h)
-    adotrad = 2.8948e-7 * Tcmb**2
+    adotrad = sp.sqrt(omega_r)/rh
 
-    a_0 = eta_0_approx / h * adotrad
+    a_0 = eta_0_approx * adotrad
 
     H_a0 = H.subs({a: a_0})  # H as function of t
     ha = H_a0 / H0 / rh
