@@ -226,18 +226,21 @@ def initial_cosmics():
     Initial conditions as defined in Cosmics
     """
     eta_0 = Min(1e-3 / k, 1e-1 * h)
-    adotrad = 2.8948e-7 * Tcmb**2
 
-    a_0 = eta_0 / h * adotrad
-
-    H_a0 = H.subs({a: a_0})  # H as function of t
     _omega_nu_m_a0 = (
         7.0
-        / 8.0
+        / 8.0 * N_eff
         * (4.0 / 11.0) ** (4.0 / 3.0)
-        * omega_r
-        / (1 + 7.0 / 8.0 * N_eff * (4.0 / 11.0) ** (4.0 / 3.0))
-    )
+        * omega_gamma
+    )  # omega_nu_m.subs({a: a_0})
+    omega_allr = omega_r + _omega_nu_m_a0
+
+    adotrad = sp.sqrt(omega_allr)/rh
+
+    a_0 = eta_0 * adotrad
+
+    H_a0 = H.subs({a: a_0})  # H as function of t
+    
     P_nu_m_a0 = 1 / 3 * _omega_nu_m_a0  # P_nu_m.subs({a: a_0})
     ha = H_a0 / H0 / rh
     amnu_0 = a_0 * massive_nu_total_mass / (N_massive_nu * kb * T_0)
@@ -343,7 +346,6 @@ def initial_camb():
     # risk!
     a_0 = sp.exp(lna_0)
     eta_0 = eta.subs({a: a_0})
-    adotrad = 2.8948e-7 * Tcmb ** 2
     C_nu = N_massive_nu / (2 * np.pi) ** 2 / rho_ev
     _omega_nu_m_a0 = (
         7.0
@@ -452,18 +454,18 @@ def initial_class():
     # the initial time is same as in Cosmics,
     # we do not set it iteratively as in CLASS
     eta_0_approx = Min(1e-3 / k, 1e-1 * h)
-    adotrad = 2.8948e-7 * Tcmb**2
 
-    a_0 = eta_0_approx / h * adotrad
-
-    omega_nu_m_a0 = (
+    omega_nu_tot = (
         7.0
-        / 8.0
+        / 8.0 * N_eff
         * (4.0 / 11.0) ** (4.0 / 3.0)
-        * omega_r
-        / (1 + 7.0 / 8.0 * N_eff * (4.0 / 11.0) ** (4.0 / 3.0))
+        * omega_gamma
     )  # omega_nu_m.subs({a: a_0})
-    omega_allr = omega_r + omega_nu_m_a0
+    omega_allr = omega_gamma + omega_nu_tot
+
+    adotrad = sp.sqrt(omega_allr)/rh
+
+    a_0 = eta_0_approx * adotrad
     amnu_0 = a_0 * massive_nu_total_mass / (N_massive_nu * kb * T_0)
 
     H_a0 = H.subs({a: a_0})  # H as function of t
@@ -477,7 +479,7 @@ def initial_class():
     # om=H0*Omega_m/sqrt(Omega_r) [h Mpc^-1]
     om = omega_m / sp.sqrt(omega_allr) / rh
     # neutrino/radiation (constant) ratio [1]
-    fracnu = (omega_neu + omega_nu_m_a0) / omega_allr
+    fracnu = omega_nu_tot / omega_allr
     # dark matter/matter (constant) ratio[1]
     fraccdm = omega_dm / omega_m
     # baryon/matter (constant) ratio [1]
@@ -916,7 +918,7 @@ fun_etai = Function("etai", integrand, t)
 fun_omega_l_a = Function("omega_l_a", omega_l_a, a)
 fun_omega_k = Function("omega_k", omega_k)
 fun_omega_nu_m = Function("omega_nu_m", omega_nu_m, a)
-fun_P_nu_m = Function("P_nu_m", P_nu_m * a**-4, a)
+fun_P_nu_m = Function("P_nu_m", P_nu_m, a)
 
 
 fun_taudot_interp = Function("taudot_interp", taudot_interp(a), a)
