@@ -35,8 +35,10 @@ class LinearPerturbationApprox(LinearPerturbationBase):
 
         where *option* can be one the following keywords:
 
-        - ``EH`` for `Eisenstein & Hu, 1998, ApJ, 511, 5 (default) <https://arxiv.org/abs/astro-ph/9710252>`_
-        - ``BBKS`` for BBKS as summarized by `Peacock, 1997, MNRAS, 284, 885 <https://arxiv.org/abs/astro-ph/9608151>`_
+        - ``EH`` for `Eisenstein & Hu, 1998, ApJ, 511, 5 (default)
+            <https://arxiv.org/abs/astro-ph/9710252>`_
+        - ``BBKS`` for BBKS as summarized by `Peacock, 1997, MNRAS, 284, 885
+            <https://arxiv.org/abs/astro-ph/9608151>`_
 
         **For developers:** in order to compare the codes :math:`\textsf{PyCosmo}` and
         :math:`\texttt{CCL}` in terms of linear matter power spectrum computed with
@@ -203,7 +205,7 @@ class LinearPerturbationApprox(LinearPerturbationBase):
         """
         a = np.atleast_1d(a)
         a_temp = np.append(a, [1.0])
-        acube = a_temp ** 3
+        acube = a_temp**3
         hbyh0 = np.sqrt(self._background._H2_H02_a(a=a_temp))
         g = (
             hbyh0
@@ -274,15 +276,15 @@ class LinearPerturbationApprox(LinearPerturbationBase):
         # using equation in section 2.4 of notes
         norm = (
             2.0
-            * np.pi ** 2
-            * self._params.deltah_norm ** 2
+            * np.pi**2
+            * self._params.deltah_norm**2
             * (self._params.c / self._params.H0) ** (3.0 + self._params.n)
         )
 
         if diag_only:
-            pk = norm * growth ** 2 * k ** self._params.n * T_k ** 2
+            pk = norm * growth**2 * k**self._params.n * T_k**2
         else:
-            pk = norm * growth ** 2 * (k ** self._params.n * T_k ** 2).reshape(-1, 1)
+            pk = norm * growth**2 * (k**self._params.n * T_k**2).reshape(-1, 1)
         return pk
 
     def _transfer_BBKS(self, k):
@@ -297,7 +299,7 @@ class LinearPerturbationApprox(LinearPerturbationBase):
 
         if self._params.pk_type == "BBKS_CCL":
             tfac = self._params.Tcmb / 2.7
-            q_pd = q_pd * tfac ** 2
+            q_pd = q_pd * tfac**2
 
         tk = (
             np.log(1.0 + 2.34 * q_pd)
@@ -357,9 +359,9 @@ class LinearPerturbationApprox(LinearPerturbationBase):
         R = (
             31.5
             * self._params.omega_b
-            * self._params.h ** 2
+            * self._params.h**2
             * self._params._sigma_27 ** (-4)
-            * (z / 10 ** 3) ** (-1.0)
+            * (z / 10**3) ** (-1.0)
         )
 
         return R
@@ -382,10 +384,10 @@ class LinearPerturbationApprox(LinearPerturbationBase):
 
         # Define the needed variables as in Eqs. (10), (20)
         q = k / (13.41 * self._params._k_eq)
-        C = 14.2 / alpha_c + 386.0 / (1.0 + 69.9 * q ** 1.08)
+        C = 14.2 / alpha_c + 386.0 / (1.0 + 69.9 * q**1.08)
 
         T_0 = np.log(np.e + 1.8 * beta_c * q) / (
-            np.log(np.e + 1.8 * beta_c * q) + C * q ** 2
+            np.log(np.e + 1.8 * beta_c * q) + C * q**2
         )
 
         return T_0
@@ -438,7 +440,7 @@ class LinearPerturbationApprox(LinearPerturbationBase):
 
         gamma_eff = (
             (self._params.omega_m + self._params.omega_nu_m)
-            * self._params.h ** 2
+            * self._params.h**2
             * (
                 np.sqrt(self._params._alpha_nu)
                 + (1.0 - np.sqrt(self._params._alpha_nu))
@@ -455,7 +457,7 @@ class LinearPerturbationApprox(LinearPerturbationBase):
                   511, 1
                   q_eff = k * Sigma_2.7^2 / (Gamma_eff * Mpc^-1)
         """
-        q_eff = k * self._params._sigma_27 ** 2.0 / self._gamma_eff(k)
+        q_eff = k * self._params._sigma_27**2.0 / self._gamma_eff(k)
 
         return q_eff
 
@@ -507,9 +509,9 @@ class LinearPerturbationApprox(LinearPerturbationBase):
 
         b_val = 1.0 + (
             1.24
-            * (self._params._f_nu ** 0.64)
+            * (self._params._f_nu**0.64)
             * (self._params.N_massive_nu ** (0.3 + 0.6 * self._params._f_nu))
-        ) / (q_nu ** -1.6 + q_nu ** 0.8)
+        ) / (q_nu**-1.6 + q_nu**0.8)
 
         return b_val
 
@@ -525,8 +527,8 @@ class LinearPerturbationApprox(LinearPerturbationBase):
 
         q = (
             k
-            * self._params._sigma_27 ** 2.0
-            * ((self._params.omega_m + self._params.omega_nu_m) * self._params.h ** 2)
+            * self._params._sigma_27**2.0
+            * ((self._params.omega_m + self._params.omega_nu_m) * self._params.h**2)
             ** -1.0
         )
 
@@ -617,11 +619,11 @@ class LinearPerturbationApprox(LinearPerturbationBase):
         ):
             omh2 = (
                 self._params.omega_m + self._params.omega_nu_m
-            ) * self._params.h ** 2
+            ) * self._params.h**2
 
             self._params._k_Silk = (
                 1.6
-                * (self._params.omega_b * self._params.h ** 2) ** 0.52
+                * (self._params.omega_b * self._params.h**2) ** 0.52
                 * (omh2) ** 0.73
                 * (1.0 + (10.4 * omh2) ** -0.95)
             )  # Eq. (7), units: Mpc^-1
@@ -662,35 +664,35 @@ class LinearPerturbationApprox(LinearPerturbationBase):
                 + (3 - 2 * self._params.omega_b / self._params.omega_m)
                 * np.sqrt((17.2 * omh2) ** 2 + 1)
             )
-            self._params._beta_node = 8.41 * omh2 ** 0.435
+            self._params._beta_node = 8.41 * omh2**0.435
 
         else:
 
             omh2_nu = (
                 self._params.omega_m + self._params.omega_nu_m
-            ) * self._params.h ** 2
-            omb2_nu = self._params.omega_b * self._params.h ** 2
+            ) * self._params.h**2
+            omb2_nu = self._params.omega_b * self._params.h**2
 
             # equations for massive neutrinos from Eisenstein & Hu, 1999, ApJ, 511, 1
 
             # Redshift at matter-radiation equality, Eq. (2) in Eisenstein & Hu, 1998,
             # ApJ, 496, 2 (modified to include Omega_nu_m in Omega_m)
-            z_equality_nu = 2.5e4 * omh2_nu * self._params._sigma_27 ** -4
-            b_1_nu = 0.313 * omh2_nu ** -0.419 * (1.0 + 0.607 * omh2_nu ** 0.674)
-            b_2_nu = 0.238 * omh2_nu ** 0.223
+            z_equality_nu = 2.5e4 * omh2_nu * self._params._sigma_27**-4
+            b_1_nu = 0.313 * omh2_nu**-0.419 * (1.0 + 0.607 * omh2_nu**0.674)
+            b_2_nu = 0.238 * omh2_nu**0.223
             z_drag_nu = (
                 1291.0
-                * (omh2_nu ** 0.251)
-                / (1.0 + 0.659 * omh2_nu ** 0.828)
+                * (omh2_nu**0.251)
+                / (1.0 + 0.659 * omh2_nu**0.828)
                 * (
                     1.0
-                    + b_1_nu * (self._params.omega_b * self._params.h ** 2) ** b_2_nu
+                    + b_1_nu * (self._params.omega_b * self._params.h**2) ** b_2_nu
                 )
             )  # Redshift at drag epoch, Eq. (4)
 
             # Wave vector values, modified to include Omega_nu_m in Omega_m
             self._params._k_eq_nu = (
-                7.46e-2 * omh2_nu * self._params._sigma_27 ** -2
+                7.46e-2 * omh2_nu * self._params._sigma_27**-2
             )  # Eq. (3), units: Mpc^-1
 
             # sound horizon given by Eq. (4) in Eisenstein & Hu, 1999, ApJ, 511, 1
@@ -742,7 +744,7 @@ class LinearPerturbationApprox(LinearPerturbationBase):
                 * (5.0 - 2 * (p_c + p_cb))
                 / (5.0 - 4.0 * p_cb)
                 * (
-                    (1.0 - 0.553 * f_nub + 0.126 * f_nub ** 3.0)
+                    (1.0 - 0.553 * f_nub + 0.126 * f_nub**3.0)
                     / (1.0 - 0.193 * np.sqrt(f_nu) + 0.169 * f_nu)
                 )
                 * (1.0 + y_d) ** (p_cb - p_c)
