@@ -28,8 +28,9 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
 
     .. Warning ::
         NonLinearPerturbationHalofit not supported by the Boltzmann solver yet.
-        Calling any function from this module while using the Boltzmann solver (pk_type = 'boltz') will return
-        **AttributeError: 'NoneType' object has no attribute 'function'**
+        Calling any function from this module while using the Boltzmann solver (pk_type
+        = 'boltz') will return **AttributeError: 'NoneType' object has no attribute
+        'function'**
     """
 
     def __init__(self, cosmo):
@@ -38,8 +39,8 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
         self._lin_pert = cosmo.lin_pert
 
     def k_nl(self, a):
-        r"""Computes the non-linear wave number :math:`k_{nl}` as a function of the scale
-        factor a.
+        r"""Computes the non-linear wave number :math:`k_{nl}` as a function of the
+        scale factor a.
 
         :param a: scale factor [1]
         :return: k_nl: non-linear wave number [:math:`\mathrm{Mpc}^{-1}`]
@@ -50,7 +51,7 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
         k_nl = np.zeros(len(aa))
         for i in range(len(aa)):
             # Delta^2=k ** 3*P(k)/(2 pi ** 2)
-            del2 = self._lin_pert.powerspec_a_k(aa[i], k)[0] * k ** 3 / 2.0 / np.pi ** 2
+            del2 = self._lin_pert.powerspec_a_k(aa[i], k)[0] * k**3 / 2.0 / np.pi**2
             # k_nl defined such that Delta^2(k_nl)=1
             k_nl[i] = np.interp(1.0, del2, k)
             if k_nl[i] < 10 ** logk_ran[0] or k_nl[i] > 10 ** logk_ran[1]:
@@ -80,7 +81,8 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
         where *option* can be one the following keywords:
 
         - ``halofit`` (default) for
-           `Smith et al., 2003, MNRAS, 341, 1311 <https://arxiv.org/abs/astro-ph/0207664>`_
+           `Smith et al., 2003, MNRAS, 341, 1311
+            <https://arxiv.org/abs/astro-ph/0207664>`_
         - ``rev_halofit`` for revision by
             `Takahashi et al., 2012, ApJ, 761, 152 <https://arxiv.org/abs/1208.2701>`_
 
@@ -203,13 +205,13 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
         """Returns the matter power spectrum per unit lnk from an
         input matter power spectrum per unit k."""
 
-        return k ** 3 * pk / (2 * np.pi ** 2)
+        return k**3 * pk / (2 * np.pi**2)
 
     def _D_to_pk(self, D, k):
         """Returns the matter power spectrum per unit k from an
         input matter power spectrum per unit lnk."""
 
-        return (2 * np.pi ** 2) * D / k ** 3
+        return (2 * np.pi**2) * D / k**3
 
     def _k_sig(self, Dlin, a, k):
         """Computes the scale k_sig which satisfies sig^2(1/ksig) = 1 where
@@ -268,7 +270,7 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
         # sig-1.0 = %d' %(np.abs(sig-1.0))
 
         y = k / ksig
-        ysq = y ** 2
+        ysq = y**2
         # Effective index, equation (C7)
         # n = -3 - dlnsig^2/dlnR
         #   = -3 + 2 int dlnk Dlin (k/ksig)^2 Wgauss(k/ksig) ** 2
@@ -279,7 +281,7 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
         C = (
             (np3 + 1.0) ** 2
             - 1.0
-            - 4.0 * np.trapz(ysq ** 2 * np.exp(-ysq) * Dlin / k, x=k)
+            - 4.0 * np.trapz(ysq**2 * np.exp(-ysq) * Dlin / k, x=k)
         )
 
         return ksig, np3, C
@@ -301,15 +303,15 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
 
         # Dimensionless wavenumber, below Eq. (C2)
         y = k / ksig
-        ysq = y ** 2
+        ysq = y**2
         # Effective index, equation (C7)
         # n = -3 - dlnsig^2/dlnR
         #   = -3 + 2 int dlnk Dlin (k/ksig)^2 Wgauss(k/ksig) ** 2
         # np3 = 2*np.trapz(ysq*np.exp(-ysq)*Dlin/k,x=k)
         n = np3 - 3.0
-        n2 = n ** 2
+        n2 = n**2
         n3 = n2 * n
-        n4 = n2 ** 2
+        n4 = n2**2
         # Spectral curvature, equation (C8)
         # C = - d^2lnsig^2/dlnR^2
         #   = 2(n+3) + (n+3)^2 - 4 int dlnk Dlin (k/ksig)^4 Wgauss(k/ksig) ** 2
@@ -373,10 +375,10 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
                 "non linear model {} not implemented".format(model)
             )
 
-        a_hf = 10 ** lga
-        b = 10 ** lgb
-        c = 10 ** lgc
-        nu = 10 ** lgnu
+        a_hf = 10**lga
+        b = 10**lgb
+        c = 10**lgc
+        nu = 10**lgnu
 
         # omega_m_z dependent functions
         # 1st case: Matter dominated universe
@@ -389,12 +391,12 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
         else:
             w_z = self._background._w_a(a=a)
 
-            f1a = omega_m_z ** -0.0732
-            f2a = omega_m_z ** -0.1423
-            f3a = omega_m_z ** 0.0725
-            f1b = omega_m_z ** -0.0307
-            f2b = omega_m_z ** -0.0585
-            f3b = omega_m_z ** 0.0743
+            f1a = omega_m_z**-0.0732
+            f2a = omega_m_z**-0.1423
+            f3a = omega_m_z**0.0725
+            f1b = omega_m_z**-0.0307
+            f2b = omega_m_z**-0.0585
+            f3b = omega_m_z**0.0743
 
             frac1 = self._params.omega_l / (self._params.omega_l + self._params.omega_k)
             we = frac1 * w_z + 1.0 / 3.0 * (1.0 - frac1)
@@ -419,7 +421,7 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
             a_hf
             * y ** (2 + 3 * f1)
             / (ysq + mu * y + nu)
-            / (1 + b * y ** f2 + (c * f3 * y) ** (3 - gamma))
+            / (1 + b * y**f2 + (c * f3 * y) ** (3 - gamma))
         )
 
         return DQ + DH
@@ -434,7 +436,7 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
         :param Dlin: P(k) linear-theory matter power spectrum P(k) [Mpc^3]
         :return: 1D linear displacement variance, as defined in eq.4 in Mead et al, 2015
         """
-        integr = 1.0 / 3 * np.trapz(Dlin / (k ** 3), x=k, axis=1)
+        integr = 1.0 / 3 * np.trapz(Dlin / (k**3), x=k, axis=1)
         sigmav = np.sqrt(integr)
         return np.sqrt(sigmav)
 
@@ -449,7 +451,7 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
         R = 100.0 / self._params.h
         T = 3 / ((k * R) ** 3) * (np.sin(k * R) - np.cos(k * R))
         # T = self.T(k * R)
-        integr = 1.0 / 3 * np.trapz((Dlin / (k ** 3)) * (T ** 2), x=k, axis=1)
+        integr = 1.0 / 3 * np.trapz((Dlin / (k**3)) * (T**2), x=k, axis=1)
         sigma_d100 = np.sqrt(integr)
         return sigma_d100
 
@@ -467,8 +469,8 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
         w = (
             3 / ((k * R) ** 3) * (np.sin(k * R) - np.cos(k * R))
         )  # top hat window function
-        res = np.trapz(k ** 3 * Dlin[0] * w ** 2, lnk)
-        sig8z = np.sqrt(1.0 / (2.0 * np.pi ** 2) * res)
+        res = np.trapz(k**3 * Dlin[0] * w**2, lnk)
+        sig8z = np.sqrt(1.0 / (2.0 * np.pi**2) * res)
 
         return sig8z
 
@@ -496,5 +498,5 @@ class NonLinearPerturbationHaloFit(NonLinearPerturbationBase):
         # Newton's gravitational constant as in Mo, Bosch & White "Galaxy
         # Formation and Evolution" (2010)
         G = 4.299e-9
-        rho = 3 * self._params.H0 ** 2 / (8 * np.pi * G)
+        rho = 3 * self._params.H0**2 / (8 * np.pi * G)
         return rho
