@@ -15,14 +15,12 @@
 # program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-import copy
 from functools import partial
 
 import numpy as np
 
 from ._scipy_utils import interp1d
 
-
 try:
     profile
 except NameError:
@@ -73,9 +71,10 @@ class Obs(object):
     where the function :meth:`cl` is documented below.
 
     .. Warning ::
-        Obs not supported by the Boltzmann solver yet, since it uses the Projection class. 
-        Calling any function from this module while using the Boltzmann solver (pk_type = 'boltz') will return 
-        **ValueError: you must set pk_nonlin_type to access projections**
+        Obs not supported by the Boltzmann solver yet, since it uses the Projection
+        class.  Calling any function from this module while using the Boltzmann solver
+        (pk_type = 'boltz') will return **ValueError: you must set pk_nonlin_type to
+        access projections**
     """
 
     def __init__(self):
@@ -214,53 +213,31 @@ class Obs(object):
 
     def bin_setup(self, obsparams):
         """
-        Sets up the redshift selection functions, i.e., each redshift selection function
+        Set up the redshift selection functions, i.e. each redshift selection function
         is either calculated from the default hard coded ones or the tabulated selection
         functions are read in and saved as attributes in self.n.
 
         :param obsparams: dictionary containing specifications for observable
-        :return: galaxy selection function in redshift
+        :return:
         """
 
         self.n = [0, 0]
-        if obsparams["probes"].count(obsparams["probes"][0]) == len(
-            obsparams["probes"]
-        ):
-            nzmode = obsparams["nz"][0]
+        for i in range(len(obsparams["probes"])):
+            nzmode = obsparams["nz"][i]
             if nzmode is not None:
                 print(
                     "Setting up galaxy selection function for {}.".format(
-                        obsparams["probes"][0]
+                        obsparams["probes"][i]
                     )
                 )
                 if nzmode in ["cfhtlens", "custom"]:
-                    path2zdist = obsparams["path2zdist"][0]
+                    path2zdist = obsparams["path2zdist"][i]
                     z, selec = self.nz(obsparams, nzmode, path2zdist)
                 else:
                     z, selec = self.nz(obsparams, nzmode)
-                self.n[0] = interp1d(z, selec, bounds_error=False, fill_value=0.0)
-                self.n[1] = copy.deepcopy(self.n[0])
+                self.n[i] = interp1d(z, selec, bounds_error=False, fill_value=0.0)
             else:
-                self.n[0] = None
-                self.n[1] = copy.deepcopy(self.n[0])
-
-        else:
-            for i in range(len(obsparams["probes"])):
-                nzmode = obsparams["nz"][i]
-                if nzmode is not None:
-                    print(
-                        "Setting up galaxy selection function for {}.".format(
-                            obsparams["probes"][i]
-                        )
-                    )
-                    if nzmode in ["cfhtlens", "custom"]:
-                        path2zdist = obsparams["path2zdist"][i]
-                        z, selec = self.nz(obsparams, nzmode, path2zdist)
-                    else:
-                        z, selec = self.nz(obsparams, nzmode)
-                    self.n[i] = interp1d(z, selec, bounds_error=False, fill_value=0.0)
-                else:
-                    self.n[i] = None
+                self.n[i] = None
 
     def windows(self, obsparams):
         r"""
@@ -398,7 +375,7 @@ class Obs(object):
         a_temp = np.concatenate(
             (np.linspace(amin, a_vec[0], anum, endpoint=False), a_vec)
         )
-        pz = n(1.0 / a_temp - 1.0) / a_temp ** 2
+        pz = n(1.0 / a_temp - 1.0) / a_temp**2
         chi = cosmo.background.dist_rad_a(a=a_temp)
         chi_a = cosmo.background.dist_rad_a(a=a_vec)
         rchi_a = cosmo.background.dist_trans_a(a=a_vec)
@@ -475,12 +452,12 @@ class Obs(object):
             # this sets the redshift distortion parameter used for RSD
             # denoted with beta in literature, e.g. in text after eq. (25)
             # in https://arxiv.org/pdf/astro-ph/0605302.pdf
-            beta_rsd = cosmo.params.omega_m ** 0.6 / obsparams["bias"]
+            beta_rsd = cosmo.params.omega_m**0.6 / obsparams["bias"]
 
             # additional component to the window function of galaxy clustering due to
             # RSD, according to eq. (27) in https://arxiv.org/pdf/astro-ph/0605302.pdf
             rsd_corr = 1.0 + beta_rsd * (
-                (2 * ells ** 2.0 + 2.0 * ells - 1) / ((2 * ells + 3) * (2 * ells - 1))
+                (2 * ells**2.0 + 2.0 * ells - 1) / ((2 * ells + 3) * (2 * ells - 1))
                 - (ells * (ells - 1)) / ((2 * ells - 1) * (2 * ells + 1))
                 - ((ells + 1) * (ells + 2)) / ((2 * ells + 1) * (2 * ells + 3))
             )
@@ -873,7 +850,7 @@ class Obs(object):
         :return: Linear intrinsic alignment amplitude for current value of h
         """
 
-        c1 = 5.0 * 10 ** -14 * cosmo.params.h ** -2 * cosmo.params.msun ** -1
+        c1 = 5.0 * 10**-14 * cosmo.params.h**-2 * cosmo.params.msun**-1
 
         return c1
 
@@ -885,5 +862,5 @@ class Obs(object):
         :return: critical density today, [rhoc] = kg/Mpc^3
         """
 
-        rhoc = cosmo.params.rho_crit * cosmo.params.msun * cosmo.params.h ** 2
+        rhoc = cosmo.params.rho_crit * cosmo.params.msun * cosmo.params.h**2
         return rhoc
