@@ -35,7 +35,7 @@ class _PowerSpecCache:
             kk = a
             if isinstance(k, np.ndarray):
                 kk = k.data.tobytes()
-            key = (pickle.dumps(power_spec_function), ak, kk, diag_only)
+            key = (power_spec_function.__func__.__qualname__, ak, kk, diag_only)
             if key not in self._cache:
                 self._cache[key] = power_spec_function(a, k, diag_only)
             return self._cache[key]
